#include "level.h"
#include "world.h"
#include "mario.h"
#include "score.h"
#include "ennemi.h"
#include "keyboard.h"
#include <plateforme.h>
#include <tuyau.h>

#include <gint/display.h>
#include <gint/std/stdlib.h>
#include <gint/keyboard.h>
#include <gint/timer.h>
#include <gint/std/string.h>
#include <gint/std/stdio.h>

void malloc_error()
{
	extern image_t img_ram;
	timer_stop(0);
	dimage(0,0,&img_ram);
	dupdate();
	while (1)
		mkb_getkey();
}

//						width height startx starty	array
static void init_level(int w, int h, int x, int y, cell_t const * a)
{
	// Resets mario's vx
	mario.p.vx=0; mario.p.vy=0;

	// Free the previous map
	if (map_current)
		free(map_current);

	// If the new map size is null => invalid map, return
	if (0==w*h)
		return;

	// Calculates the new struct size
	int size= 4*sizeof(int) + sizeof(cell_t)*w*h;
	map_current=(map_t*)malloc(size);
	if (map_current==0)
		malloc_error();

	// Copy the map to ram
	map_current->w = w;
	map_current->h = h;
	mario.p.x = map_current->start_x = x;
	mario.p.y = map_current->start_y = y;
	memcpy(map_current->data, a, sizeof(cell_t)*w*h);
}

void init_ennemies(ennemi_t * table)
{
	if (ennemis_global)
	{
		free(ennemis_global);
	}
	if (0==ennemis_global_size)
		return;
	int size=sizeof(ennemi_t)*ennemis_global_size;
	ennemis_global=malloc(size);
	if (ennemis_global==0)
		malloc_error();

	memcpy(ennemis_global, table, size);
}

static void init_plateformes(plateforme_t * table)
{
	if (plateformes)
	{
		free(plateformes);
		plateformes=0;
	}
	if (0==table)
		return;
	int size=sizeof(plateforme_t)*plateforme_table_size;
	plateformes=malloc(size);
	if (plateformes==0)
		malloc_error();

	memcpy(plateformes, table, size);
}

/*
	ennemis_global_size=10;
	ennemi_t ennemies0[]=
	{
		GOOMBA(176,16,-1),
		GOOMBA(321,16,-1),
		GOOMBA(409,16,-1),
		GOOMBA(421,16,-1),
		GOOMBA(640,80,-1),
		GOOMBA(656,80,-1),
		GOOMBA(776,16,-1),
		GOOMBA(788,16,-1),
		KOOPA_V(856,16,-1),
		GOOMBA(912,16,-1),
		GOOMBA(924,16,-1)
	};
	init_ennemies(ennemies0);

	plateforme_t plateforme0[]=
	{
		PLATEFORME_MOVING_H(15,25,16,1,0,60)
	};
	plateforme_table_size=1;
	init_plateformes(plateforme0);*/

void set_level(int w, int l)
{
	new_level();
	set_teleporteurs(0,0);
	if (map_current)
	{	free(map_current);
		map_current=0;
	}
	ennemis_global_size=0;
	plateforme_table_size=0;

	if (w+1==1 && l+1==1) // 1-1
	{
		const int w=226, h=13;
		const int x=25, y=16;
		cell_t a[]=	
		{
			{EARTH,0x01},		{EARTH,0x00},		{COLLINE,0x01},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{COLLINE,0x11},		{COLLINE,0x01},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{0,0},				{COLLINE,0x11},		{COLLINE,0x10},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{COLLINE,0x11},		{COLLINE,0x21},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{COLLINE,0x21},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{NUAGE,0x01},		{NUAGE,0x00},		{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{NUAGE,0x11},		{NUAGE,0x10},		{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{NUAGE,0x21},		{NUAGE,0x20},		{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{BUISSON,0x00},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{BUISSON,0x10},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{BUISSON,0x10},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{BUISSON,0x10},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{BUISSON,0x20},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{COLLINE,0x01},		{0,0},				{0,0},				{GIFT,0x11},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{COLLINE,0x11},		{COLLINE,0x10},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{COLLINE,0x21},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{NUAGE,0x01},		{NUAGE,0x00},		{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{0,0},				{0,0},				{0,0},				{BRICK,0},			{0,0},				{0,0},				{0,0},				{0,0},				{NUAGE,0x11},		{NUAGE,0x10},		{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{0,0},				{0,0},				{0,0},				{GIFT,0x21},		{0,0},				{0,0},				{0,0},				{0,0},				{NUAGE,0x21},		{NUAGE,0x20},		{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{0,0},				{0,0},				{0,0},				{BRICK,0},			{0,0},				{0,0},				{0,0},				{GIFT,0x11},		{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{BUISSON,0x00},		{0,0},				{0,0},				{GIFT,0x11},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{BUISSON,0x10},		{0,0},				{0,0},				{BRICK,0},			{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{BUISSON,0x20},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{NUAGE,0x01},		{NUAGE,0x00},		{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{TUYAU,0x03},		{TUYAU,0x02},		{0,0},				{0,0},				{0,0},				{0,0},				{NUAGE,0x11},		{NUAGE,0x10},		{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{TUYAU,0x13},		{TUYAU,0x12},		{0,0},				{0,0},				{0,0},				{0,0},				{NUAGE,0x11},		{NUAGE,0x10},		{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{NUAGE,0x11},		{NUAGE,0x10},		{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{NUAGE,0x21},		{NUAGE,0x20},		{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{NUAGE,0x01},		{NUAGE,0x00},		{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{NUAGE,0x11},		{NUAGE,0x10},		{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{TUYAU,0x03},		{TUYAU,0x03},		{TUYAU,0x02},		{0,0},				{0,0},				{0,0},				{0,0},				{NUAGE,0x11},		{NUAGE,0x10},		{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{TUYAU,0x13},		{TUYAU,0x13},		{TUYAU,0x12},		{0,0},				{0,0},				{0,0},				{0,0},				{NUAGE,0x21},		{NUAGE,0x20},		{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{BUISSON,0x00},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{BUISSON,0x10},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{BUISSON,0x10},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{BUISSON,0x20},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{TUYAU,0x03},		{TUYAU,0x03},		{TUYAU,0x03},		{TUYAU,0x02},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{TUYAU,0x13},		{TUYAU,0x13},		{TUYAU,0x13},		{TUYAU,0x12},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{COLLINE,0x01},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{COLLINE,0x11},		{COLLINE,0x01},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{0,0},				{COLLINE,0x11},		{COLLINE,0x10},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{COLLINE,0x11},		{COLLINE,0x21},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{COLLINE,0x21},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{NUAGE,0x01},		{NUAGE,0x00},		{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{TUYAU,0x03},		{TUYAU,0x03},		{TUYAU,0x03},		{TUYAU,0x02},		{0,0},				{0,0},				{0,0},				{NUAGE,0x11},		{NUAGE,0x10},		{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{TUYAU,0x13},		{TUYAU,0x13},		{TUYAU,0x13},		{TUYAU,0x12},		{0,0},				{0,0},				{0,0},				{NUAGE,0x21},		{NUAGE,0x20},		{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{BUISSON,0x00},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{BUISSON,0x10},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{BUISSON,0x10},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{BUISSON,0x10},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{BUISSON,0x20},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{COLLINE,0x01},		{0,0},				{0,0},				{0,0},				{GIFT,0x131},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{COLLINE,0x11},		{COLLINE,0x10},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{NUAGE,0x01},		{NUAGE,0x00},		{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{COLLINE,0x21},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{NUAGE,0x11},		{NUAGE,0x10},		{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{NUAGE,0x21},		{NUAGE,0x20},		{0,0},
			{EARTH,0x21},		{EARTH,0x20},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x01},		{EARTH,0x00},		{BUISSON,0x00},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{BUISSON,0x10},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{BUISSON,0x20},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{NUAGE,0x01},		{NUAGE,0x00},		{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{NUAGE,0x11},		{NUAGE,0x10},		{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{0,0},				{0,0},				{0,0},				{BRICK,0},			{0,0},				{0,0},				{0,0},				{0,0},				{NUAGE,0x11},		{NUAGE,0x10},		{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{0,0},				{0,0},				{0,0},				{GIFT,0x21},		{0,0},				{0,0},				{0,0},				{0,0},				{NUAGE,0x11},		{NUAGE,0x10},		{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{0,0},				{0,0},				{0,0},				{BRICK,0},			{0,0},				{0,0},				{0,0},				{0,0},				{NUAGE,0x21},		{NUAGE,0x20},		{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{BRICK,0},			{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{BRICK,0},			{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{BRICK,0},			{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{BRICK,0},			{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{BRICK,0},			{0,0},				{NUAGE,0x01},		{NUAGE,0x00},
			{EARTH,0x21},		{EARTH,0x20},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{BRICK,0},			{0,0},				{NUAGE,0x11},		{NUAGE,0x10},
			{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{BRICK,0},			{0,0},				{NUAGE,0x11},		{NUAGE,0x10},
			{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{BRICK,0},			{0,0},				{NUAGE,0x21},		{NUAGE,0x20},
			{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x01},		{EARTH,0x00},		{BUISSON,0x00},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{BUISSON,0x10},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{BUISSON,0x10},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{BRICK,0},			{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{BUISSON,0x20},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{BRICK,0},			{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{BRICK,0},			{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{0,0},				{0,0},				{0,0},				{BRICK,0x15},		{0,0},				{0,0},				{0,0},				{GIFT,0x11},		{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{COLLINE,0x01},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{COLLINE,0x11},		{COLLINE,0x01},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{0,0},				{COLLINE,0x11},		{COLLINE,0x10},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{COLLINE,0x11},		{COLLINE,0x21},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{COLLINE,0x21},		{0,0},				{0,0},				{BRICK,0},			{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{0,0},				{0,0},				{0,0},				{BRICK,0x41},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{NUAGE,0x01},		{NUAGE,0x00},		{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{NUAGE,0x11},		{NUAGE,0x10},		{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{0,0},				{0,0},				{0,0},				{GIFT,0x11},		{0,0},				{0,0},				{0,0},				{0,0},				{NUAGE,0x21},		{NUAGE,0x20},		{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{BUISSON,0x00},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{BUISSON,0x10},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{BUISSON,0x10},		{0,0},				{0,0},				{GIFT,0x11},		{0,0},				{0,0},				{0,0},				{GIFT,0x21},		{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{BUISSON,0x10},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{BUISSON,0x20},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{COLLINE,0x01},		{0,0},				{0,0},				{GIFT,0x11},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{COLLINE,0x11},		{COLLINE,0x10},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{COLLINE,0x21},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{NUAGE,0x01},		{NUAGE,0x00},
			{EARTH,0x11},		{EARTH,0x10},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{NUAGE,0x11},		{NUAGE,0x10},
			{EARTH,0x11},		{EARTH,0x10},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{NUAGE,0x21},		{NUAGE,0x20},
			{EARTH,0x11},		{EARTH,0x10},		{0,0},				{0,0},				{0,0},				{BRICK,0},			{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x01},		{EARTH,0x10},		{BUISSON,0x00},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{BUISSON,0x10},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{BUISSON,0x20},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{BRICK,0},			{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{BRICK,0},			{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{BRICK,0},			{NUAGE,0x01},		{NUAGE,0x00},		{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{NUAGE,0x11},		{NUAGE,0x10},		{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{NUAGE,0x11},		{NUAGE,0x10},		{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{NUAGE,0x11},		{NUAGE,0x10},		{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{NUAGE,0x21},		{NUAGE,0x20},		{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{BRICK,0},			{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{0,0},				{0,0},				{0,0},				{BRICK,0},			{0,0},				{0,0},				{0,0},				{GIFT,0x11},		{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{0,0},				{0,0},				{0,0},				{BRICK,0},			{0,0},				{0,0},				{0,0},				{GIFT,0x11},		{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{BRICK,0},			{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{NUAGE,0x01},		{NUAGE,0x00},
			{EARTH,0x11},		{EARTH,0x10},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{NUAGE,0x11},		{NUAGE,0x10},
			{EARTH,0x11},		{EARTH,0x10},		{BLOC,0},			{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{NUAGE,0x11},		{NUAGE,0x10},
			{EARTH,0x11},		{EARTH,0x10},		{BLOC,0},			{BLOC,0},			{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{NUAGE,0x21},		{NUAGE,0x20},
			{EARTH,0x11},		{EARTH,0x10},		{BLOC,0},			{BLOC,0},			{BLOC,0},			{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{BLOC,0},			{BLOC,0},			{BLOC,0},			{BLOC,0},			{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{BUISSON,0x10},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{BUISSON,0x10},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{BLOC,0},			{BLOC,0},			{BLOC,0},			{BLOC,0},			{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{BLOC,0},			{BLOC,0},			{BLOC,0},			{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{BLOC,0},			{BLOC,0},			{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{BLOC,0},			{0,0},  			{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x01},		{EARTH,0x10},		{COLLINE,0x01},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{COLLINE,0x11},		{COLLINE,0x01},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{0,0},				{COLLINE,0x11},		{COLLINE,0x10},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{COLLINE,0x11},		{COLLINE,0x21},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{BLOC,0},			{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0x11},   	{0,0x10},
			{EARTH,0x11},		{EARTH,0x10},		{BLOC,0},			{BLOC,0},			{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0x21},   	{0,0x20},
			{EARTH,0x11},		{EARTH,0x10},		{BLOC,0},			{BLOC,0},			{BLOC,0},			{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{BLOC,0},			{BLOC,0},			{BLOC,0},			{BLOC,0},			{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x21},		{EARTH,0x20},		{BLOC,0},			{BLOC,0},			{BLOC,0},			{BLOC,0},			{0,0},				{0,0},				{0,0},				{0,0},				{NUAGE,0x01},		{NUAGE,0x00},   {0,0},
			{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{NUAGE,0x11},		{NUAGE,0x10},   {0,0},
			{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{NUAGE,0x21},		{NUAGE,0x20},   {0,0},
			{EARTH,0x01},		{EARTH,0x00},		{BLOC,0},			{BLOC,0},			{BLOC,0},			{BLOC,0},			{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{BLOC,0},			{BLOC,0},			{BLOC,0},			{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{BLOC,0},			{BLOC,0},			{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{BLOC,0},			{0,0},  			{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{BUISSON,0x20},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{COLLINE,0x01},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{COLLINE,0x11},		{COLLINE,0x10},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{COLLINE,0x21},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{TUYAU,0x03},		{TUYAU,0x02},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{NUAGE,0x01},		{NUAGE,0x00},   {0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{TUYAU,0x13},		{TUYAU,0x12},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{NUAGE,0x11},		{NUAGE,0x10},   {0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{NUAGE,0x21},		{NUAGE,0x20},		{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{BUISSON,0x00},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{BUISSON,0x10},		{0,0},				{0,0},				{BRICK,0},			{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{BUISSON,0x20},		{0,0},				{0,0},				{BRICK,0},			{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{0,0},				{0,0},				{0,0},				{GIFT,0x11},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{0,0},				{0,0},				{0,0},				{BRICK,0},			{0,0},				{0,0},				{0,0},				{NUAGE,0x01},		{NUAGE,0x00},		{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{NUAGE,0x11},		{NUAGE,0x10},		{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{NUAGE,0x11},		{NUAGE,0x10},		{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{NUAGE,0x11},		{NUAGE,0x10},		{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{NUAGE,0x21},		{NUAGE,0x20},		{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{TUYAU,0x03},		{TUYAU,0x02},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{TUYAU,0x13},		{TUYAU,0x12},		{0,0},				{0,0},				{0,0},				{0,0},				{NUAGE,0x01},		{NUAGE,0x00},		{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{BLOC,0},			{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{NUAGE,0x11},		{NUAGE,0x10},		{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{BLOC,0},			{BLOC,0},			{0,0},				{0,0},				{0,0},				{0,0},				{NUAGE,0x11},		{NUAGE,0x10},		{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{BLOC,0},			{BLOC,0},			{BLOC,0},			{0,0},				{0,0},				{0,0},				{NUAGE,0x21},		{NUAGE,0x20},		{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{BLOC,0},			{BLOC,0},			{BLOC,0},			{BLOC,0},			{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{BLOC,0},			{BLOC,0},			{BLOC,0},			{BLOC,0},			{BLOC,0},			{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{BLOC,0},			{BLOC,0},			{BLOC,0},			{BLOC,0},			{BLOC,0},			{BLOC,0},			{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{BLOC,0},			{BLOC,0},			{BLOC,0},			{BLOC,0},			{BLOC,0},			{BLOC,0},			{BLOC,0},			{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{BLOC,0},			{BLOC,0},			{BLOC,0},			{BLOC,0},			{BLOC,0},			{BLOC,0},			{BLOC,0},			{BLOC,0},			{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{BLOC,0},			{BLOC,0},			{BLOC,0},			{BLOC,0},			{BLOC,0},			{BLOC,0},			{BLOC,0},			{BLOC,0},			{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{COLLINE,0x01},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{COLLINE,0x11},		{COLLINE,0x01},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{0,0},				{COLLINE,0x11},		{COLLINE,0x10},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{COLLINE,0x11},		{COLLINE,0x21},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{COLLINE,0x21},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{BLOC,0},			{END_LEVEL,0x1102},	{END_LEVEL,0x1102},	{END_LEVEL,0x1202},	{END_LEVEL,0x1202},	{END_LEVEL,0x1202},	{END_LEVEL,0x1302},	{END_LEVEL,0x1401},	{END_LEVEL,0x1400},	{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{NUAGE,0x01},		{NUAGE,0x00},		{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{NUAGE,0x11},		{NUAGE,0x10},		{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{CASTLE,0x02},		{CASTLE,0x01},		{CASTLE,0x00},		{0,0},				{0,0},				{0,0},				{0,0},				{NUAGE,0x21},		{NUAGE,0x20},		{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{CASTLE,0x12},		{CASTLE,0x11},		{CASTLE,0x10},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{CASTLE,0x22},		{CASTLE,0x21},		{CASTLE,0x20},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{BRICK,0},			{BRICK,0},			{BRICK,0},			{BRICK,0},			{BRICK,0},			{BRICK,0},			{BRICK,0},			{BRICK,0},			{BRICK,0},			{BRICK,0},			{BRICK,0},
			{EARTH,0x11},		{EARTH,0x10},		{BRICK,0},			{BRICK,0},			{BRICK,0},			{BRICK,0},			{BRICK,0},			{BRICK,0},			{BRICK,0},			{BRICK,0},			{BRICK,0},			{BRICK,0},			{BRICK,0},
			{EARTH,0x11},		{EARTH,0x10},		{BRICK,0},			{BRICK,0},			{BRICK,0},			{BRICK,0},			{BRICK,0},			{BRICK,0},			{BRICK,0},			{BRICK,0},			{BRICK,0},			{BRICK,0},			{BRICK,0},
			{EARTH,0x11},		{EARTH,0x10},		{BRICK,0},			{BRICK,0},			{BRICK,0},			{BRICK,0},			{BRICK,0},			{BRICK,0},			{BRICK,0},			{BRICK,0},			{BRICK,0},			{BRICK,0},			{BRICK,0},
			{EARTH,0x11},		{EARTH,0x10},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{BRICK,0},			{BRICK,0},			{BRICK,0},			{COIN,0},			{0,0},				{COIN,0},			{0,0},				{0,0},				{0,0},				{0,0},				{BRICK,0},
			{EARTH,0x11},		{EARTH,0x10},		{BRICK,0},			{BRICK,0},			{BRICK,0},			{COIN,0},			{0,0},				{COIN,0},			{0,0},				{COIN,0},			{0,0},				{0,0},				{BRICK,0},
			{EARTH,0x11},		{EARTH,0x10},		{BRICK,0},			{BRICK,0},			{BRICK,0},			{COIN,0},			{0,0},				{COIN,0},			{0,0},				{COIN,0},			{0,0},				{0,0},				{BRICK,0},
			{EARTH,0x11},		{EARTH,0x10},		{BRICK,0},			{BRICK,0},			{BRICK,0},			{COIN,0},			{0,0},				{COIN,0},			{0,0},				{COIN,0},			{0,0},				{0,0},				{BRICK,0},
			{EARTH,0x11},		{EARTH,0x10},		{BRICK,0},			{BRICK,0},			{BRICK,0},			{COIN,0},			{0,0},				{COIN,0},			{0,0},				{COIN,0},			{0,0},				{0,0},				{BRICK,0},
			{EARTH,0x11},		{EARTH,0x10},		{BRICK,0},			{BRICK,0},			{BRICK,0},			{COIN,0},			{0,0},				{COIN,0},			{0,0},				{COIN,0},			{0,0},				{0,0},				{BRICK,0},
			{EARTH,0x11},		{EARTH,0x10},		{BRICK,0},			{BRICK,0},			{BRICK,0},			{COIN,0},			{0,0},				{COIN,0},			{0,0},				{0,0},				{0,0},				{0,0},				{BRICK,0},
			{EARTH,0x11},		{EARTH,0x10},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{TUYAU,0x01},		{TUYAU,0x00},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{TUYAU,0x11},		{TUYAU,0x10},		{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},				{0,0},
			{EARTH,0x11},		{EARTH,0x10},		{TUYAU,0x03},		{TUYAU,0x03},		{TUYAU,0x03},		{TUYAU,0x03},		{TUYAU,0x03},		{TUYAU,0x03},		{TUYAU,0x03},		{TUYAU,0x03},		{TUYAU,0x03},		{TUYAU,0x03},		{TUYAU,0x03}
		};
		init_level(w,h,x,y,a);

		ennemis_global_size=10;
		ennemi_t ennemies0[]=
		{
			GOOMBA(176,16,-1),
			GOOMBA(321,16,-1),
			GOOMBA(409,16,-1),
			GOOMBA(421,16,-1),
			GOOMBA(640,80,-1),
			GOOMBA(656,80,-1),
			GOOMBA(776,16,-1),
			GOOMBA(788,16,-1),
			KOOPA_V(856,16,-1),
			GOOMBA(912,16,-1),
			GOOMBA(924,16,-1)
		};
		init_ennemies(ennemies0);


		teleport_t t[]=
		{
			{57,6,  212,12, MK_DOWN},
			{222,2, 178,3, MK_RIGHT}
		};

		set_teleporteurs(t, sizeof(t)/sizeof(teleport_t));


	}
	else if (w+1==1 && l+1==2)
	{
// !b Here the generated section begins (see the end at "!e")
		const int w=226, h=13;
		const int x=25, y=16;
		cell_t a[]=	
		{
			{EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {TUYAU,0x03}, {TUYAU,0x02}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {TUYAU,0x13}, {TUYAU,0x12}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, {BRICK,0}, {0,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {0,0}, {0,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {0,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {0,0}, {0,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {0,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {0,0}, {0,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {0,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {0,0}, {0,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, {BRICK,0}, {0,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {GIFT,0x21}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {GIFT,0x11}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {GIFT,0x11}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {GIFT,0x11}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,'?'}, {0,0}, {0,0}, {GIFT,0x11}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,'?'}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {BLOC,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {BLOC,0}, {BLOC,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {BLOC,0}, {BLOC,0}, {BLOC,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {BLOC,0}, {BLOC,0}, {BLOC,0}, {BLOC,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {BLOC,0}, {BLOC,0}, {BLOC,0}, {BLOC,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {BLOC,0}, {BLOC,0}, {BLOC,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,'?'}, {0,0}, {0,0}, {BRICK,0x15}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {BLOC,0}, {BLOC,0}, {BLOC,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {BLOC,0}, {BLOC,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,'?'}, {0,0}, {0,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {BRICK,0}, {COIN,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,'?'}, {0,0}, {0,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {0,0}, {COIN,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, {0,0}, {COIN,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, {0,0}, {COIN,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {0,0}, {COIN,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {BRICK,0}, {COIN,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x21}, {EARTH,0x20}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x01}, {EARTH,0x00}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {0,0}, {COIN,0}, {0,0}, {0,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {0,0}, {COIN,0}, {0,0}, {0,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {BRICK,0}, {0,0}, {COIN,0}, {0,0}, {0,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {BRICK,0}, {0,0}, {COIN,0}, {0,0}, {0,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {BRICK,0}, {0,0}, {COIN,0}, {0,0}, {0,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {BRICK,0}, {0,0}, {COIN,0}, {0,0}, {0,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {BRICK,0}, {0,0}, {COIN,0}, {0,0}, {0,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {BRICK,0}, {0,0}, {COIN,0}, {0,0}, {0,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, {BRICK,0}, {0,0}, {COIN,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {0,0}, {COIN,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {0,0}, {COIN,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {0,0}, {COIN,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, {BRICK,0}, {0,0}, {COIN,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,'?'}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,'?'}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {TUYAU,0x03}, {TUYAU,0x03}, {TUYAU,0x02}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {TUYAU,0x13}, {TUYAU,0x13}, {TUYAU,0x12}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {TUYAU,0x03}, {TUYAU,0x03}, {TUYAU,0x03}, {TUYAU,0x02}, {0,0}, {0,0}, {0,0}, {0,0}, {COIN,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {TUYAU,0x13}, {TUYAU,0x13}, {TUYAU,0x13}, {TUYAU,0x12}, {0,0}, {0,0}, {0,0}, {0,0}, {COIN,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,'?'}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {TUYAU,0x03}, {TUYAU,0x03}, {TUYAU,0x02}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {TUYAU,0x13}, {TUYAU,0x13}, {TUYAU,0x12}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x21}, {EARTH,0x20}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x01}, {EARTH,0x00}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x21}, {EARTH,0x20}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x01}, {EARTH,0x00}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {BLOC,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {BLOC,0}, {BLOC,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {BLOC,0}, {BLOC,0}, {BLOC,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {BLOC,0}, {BLOC,0}, {BLOC,0}, {BLOC,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {BLOC,0}, {BLOC,0}, {BLOC,0}, {BLOC,0}, {BLOC,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {BLOC,0}, {BLOC,0}, {BLOC,0}, {BLOC,0}, {BLOC,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,'?'}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,'?'}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,'?'}, {0,0}, {0,0}, {0,0}, {0,'?'}, {0,0}, {0,0}, {0,0}, {COIN,0}, {0,0}, {0,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,'?'}, {0,0}, {0,0}, {0,0}, {COIN,0}, {0,0}, {0,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,'?'}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,'?'}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {BLOC,0}, {BLOC,0}, {BLOC,0}, {BLOC,0}, {BLOC,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {BLOC,0}, {BLOC,0}, {BLOC,0}, {BLOC,0}, {BLOC,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {BLOC,0}, {BLOC,0}, {BLOC,0}, {BLOC,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {BLOC,0}, {BLOC,0}, {BLOC,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {BLOC,0}, {BLOC,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {BLOC,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,'?'}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x21}, {EARTH,0x20}, {BLOC,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x01}, {EARTH,0x00}, {BLOC,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, {0,'?'}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,'?'}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, {COIN,0}, {0,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, {COIN,0}, {0,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, {COIN,0}, {0,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,'?'}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x11}, {EARTH,0x11}, {EARTH,0x01}, {EARTH,0x01}, {EARTH,0x00}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x11}, {EARTH,0x11}, {EARTH,0x11}, {EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x11}, {EARTH,0x11}, {EARTH,0x11}, {EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x11}, {EARTH,0x11}, {EARTH,0x11}, {EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x11}, {EARTH,0x11}, {EARTH,0x11}, {EARTH,0x11}, {EARTH,0x10}, {TUYAU,0x01}, {TUYAU,0x00}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x11}, {EARTH,0x11}, {EARTH,0x11}, {EARTH,0x11}, {EARTH,0x10}, {TUYAU,0x13}, {TUYAU,0x13}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x11}, {EARTH,0x11}, {EARTH,0x11}, {EARTH,0x11}, {EARTH,0x11}, {EARTH,0x01}, {EARTH,0x01}, {EARTH,0x01}, {EARTH,0x01}, {EARTH,0x01}, {EARTH,0x01}, {EARTH,0x01}, {EARTH,0x00}, 
			{EARTH,0x11}, {EARTH,0x11}, {EARTH,0x11}, {EARTH,0x11}, {EARTH,0x11}, {EARTH,0x11}, {EARTH,0x11}, {EARTH,0x11}, {EARTH,0x11}, {EARTH,0x11}, {EARTH,0x11}, {EARTH,0x11}, {EARTH,0x10}, 
			{EARTH,0x11}, {EARTH,0x11}, {EARTH,0x11}, {EARTH,0x11}, {EARTH,0x11}, {EARTH,0x11}, {EARTH,0x11}, {EARTH,0x11}, {EARTH,0x11}, {EARTH,0x11}, {EARTH,0x11}, {EARTH,0x11}, {EARTH,0x10}, 
			{EARTH,0x11}, {EARTH,0x11}, {EARTH,0x21}, {EARTH,0x21}, {EARTH,0x21}, {EARTH,0x21}, {EARTH,0x21}, {EARTH,0x21}, {EARTH,0x21}, {EARTH,0x21}, {EARTH,0x21}, {EARTH,0x21}, {EARTH,0x20}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {COIN,0}, {0,0}, {0,0}, {BRICK,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {COIN,0}, {0,0}, {0,0}, {BRICK,0}, {COIN,0}, {0,0}, {0,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {COIN,0}, {0,0}, {0,0}, {BRICK,0}, {COIN,0}, {0,0}, {0,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {COIN,0}, {0,0}, {0,0}, {BRICK,0}, {COIN,0}, {0,0}, {0,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {COIN,0}, {0,0}, {0,0}, {BRICK,0}, {COIN,0}, {0,0}, {0,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {COIN,0}, {0,0}, {0,0}, {BRICK,0}, {COIN,0}, {0,0}, {0,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {0,0}, {0,0}, {0,0}, {BRICK,0}, {COIN,0}, {0,0}, {0,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {TUYAU,0x01}, {TUYAU,0x00}, {0,0}, {BRICK,0}, {COIN,0}, {0,0}, {0,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, 
			{EARTH,0x11}, {EARTH,0x10}, {TUYAU,0x13}, {TUYAU,0x13}, {0,0}, {BRICK,0}, {COIN,0}, {0,0}, {0,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, 
			{EARTH,0x11}, {EARTH,0x20}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, 
			{EARTH,0x10}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, 
			{EARTH,0x10}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, 
			{EARTH,0x10}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x20}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{TUYAU,0x03}, {TUYAU,0x03}, {TUYAU,0x02}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{TUYAU,0x13}, {TUYAU,0x13}, {TUYAU,0x12}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x00}, {BLOC,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x10}, {BLOC,0}, {BLOC,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x10}, {BLOC,0}, {BLOC,0}, {BLOC,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x10}, {BLOC,0}, {BLOC,0}, {BLOC,0}, {BLOC,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x10}, {BLOC,0}, {BLOC,0}, {BLOC,0}, {BLOC,0}, {BLOC,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x10}, {BLOC,0}, {BLOC,0}, {BLOC,0}, {BLOC,0}, {BLOC,0}, {BLOC,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x10}, {BLOC,0}, {BLOC,0}, {BLOC,0}, {BLOC,0}, {BLOC,0}, {BLOC,0}, {BLOC,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x10}, {BLOC,0}, {BLOC,0}, {BLOC,0}, {BLOC,0}, {BLOC,0}, {BLOC,0}, {BLOC,0}, {BLOC,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x10}, {BLOC,0}, {BLOC,0}, {BLOC,0}, {BLOC,0}, {BLOC,0}, {BLOC,0}, {BLOC,0}, {BLOC,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x10}, {BLOC,0}, {END_LEVEL,0x1102},{END_LEVEL,0x1102},{END_LEVEL,0x1102},{END_LEVEL,0x1102},{END_LEVEL,0x1202}, {END_LEVEL,0x1202}, {END_LEVEL,0x1202}, {END_LEVEL,0x1302}, {END_LEVEL,0x1401}, {END_LEVEL,0x1400}, {0,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
		};
		init_level(w,h,x,y, a);

		ennemi_t ennemies0[]={
			GOOMBA(264, 16, -1),
			GOOMBA(280, 16, -1),
			GOOMBA(392, 16, -1),
			KOOPA_V(488, 16, -1),
			KOOPA_V(504, 16, -1),
			GOOMBA(808, 16, -1),
			GOOMBA(824, 16, -1),
			GOOMBA(920, 16, -1),
			GOOMBA(1144, 16, -1),
			KOOPA_V(1160, 16, -1),
			GOOMBA(1184, 16, -1),
			GOOMBA(1272, 16, -1),
			KOOPA_R(1344, 64, -1),
			GOOMBA(1368, 16, -1),
			GOOMBA(1392, 16, -1),
		};
		ennemis_global_size=11;
		init_ennemies(ennemies0);

// !e End of generated section

		

		teleport_t t[]=
		{
			{6,4,  21,12, MK_DOWN},
			{106,5, 188,12, MK_DOWN},
			{197,2, 118,4, MK_RIGHT},
			{180,5, 206,2, MK_RIGHT},
		};
		set_teleporteurs(t, sizeof(t)/sizeof(teleport_t));

		plateforme_t plateforme0[]=
		{
			PLATEFORME_MOVING_H(8*144,6*8+7,32,1,8*142,8*150)
		};
		plateforme_table_size=sizeof(plateforme0)/sizeof(plateforme_t);
		init_plateformes(plateforme0);

	}
/*
	else if (w+1==1 && l+1==3)
	{

// !b Here the generated section begins (see the end at "!e")
		const int w=279, h=14;
		const int x=25, y=32;
		cell_t a[]=	
		{
			{EARTH,0x11}, {EARTH,0x21}, {EARTH,0x21}, {EARTH,0x21}, {EARTH,0x21}, {EARTH,0x21}, {EARTH,0x21}, {EARTH,0x21}, {EARTH,0x21}, {EARTH,0x21}, {EARTH,0x21}, {EARTH,0x21}, {EARTH,0x21}, {EARTH,0x20}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {TUYAU,0x04}, {TUYAU,0x03}, {TUYAU,0x03}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {TUYAU,0x14}, {TUYAU,0x13}, {TUYAU,0x13}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x20}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{0,0}, {0,0}, {0,0}, {COIN,0}, {0,0}, {0,0}, {BRICK,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x00}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,'?'}, {0,0}, {0,0}, {BRICK,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,'?'}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, {BRICK,0}, {COIN,0}, {0,0}, {BRICK,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, {BRICK,0}, {COIN,0}, {0,0}, {BRICK,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, {BRICK,0}, {COIN,0}, {0,0}, {BRICK,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, {BRICK,0}, {COIN,0}, {0,0}, {BRICK,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,'?'}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {BLOC,0}, {BLOC,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,0}, {COIN,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {BLOC,0}, {BLOC,0}, {BLOC,0}, {BLOC,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,'?'}, {0,0}, {COIN,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {BLOC,0}, {BLOC,0}, {BLOC,0}, {BLOC,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,0}, {COIN,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {BLOC,0}, {BLOC,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,'?'}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {COIN,0}, {0,0}, {COIN,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,'?'}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,'?'}, {0,0}, {0,0}, {0,0}, {BRICK,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {GIFT,0x21}, {0,0}, {0,0}, {0,0}, {BRICK,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x20}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x00}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {BRICK,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {BRICK,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {BRICK,0}, {0,'?'}, {0,0}, {0,0}, {GIFT,0x11}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {BRICK,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {BRICK,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x20}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{0,0}, {0,0}, {0,0}, {BRICK,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{0,0}, {0,0}, {0,0}, {BRICK,0}, {0,0}, {0,0}, {0,0}, {COIN,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{0,0}, {0,0}, {0,0}, {BRICK,0}, {0,'?'}, {0,0}, {0,0}, {COIN,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{0,0}, {0,0}, {0,0}, {BRICK,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x00}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {COIN,0}, {0,0}, {COIN,0}, {0,0}, {0,'?'}, {0,0}, {0,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, {0,'?'}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, {0,0}, {0,0}, {BRICK,0}, {0,'?'}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {TUYAU,0x03}, {TUYAU,0x03}, {TUYAU,0x02}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {TUYAU,0x13}, {TUYAU,0x13}, {TUYAU,0x12}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,'?'}, {0,0}, {0,0}, {0,0}, {BRICK,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0x15}, {0,0}, {0,0}, {0,0}, {BRICK,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {BLOC,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, {0,0}, {0,0}, {0,0}, {GIFT,0x21}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0x15}, {0,0}, {0,0}, {0,0}, {BRICK,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x20}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{0,0}, {0,0}, {BRICK,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {COIN,0}, {0,0}, {0,0}, {BRICK,0}, 
			{0,0}, {0,0}, {BRICK,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {COIN,0}, {0,0}, {BRICK,0}, 
			{0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, {0,'?'}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {COIN,0}, {0,0}, {BRICK,0}, 
			{0,0}, {0,0}, {BRICK,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{0,0}, {0,0}, {BRICK,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {COIN,0}, {0,0}, {0,0}, {BRICK,0}, 
			{0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x00}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,'?'}, {0,0}, {0,0}, {0,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,'?'}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,'?'}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {BLOC,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {BLOC,0}, {BLOC,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {BLOC,0}, {BLOC,0}, {BLOC,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x20}, {BLOC,0}, {BLOC,0}, {BLOC,0}, {BLOC,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x00}, {0,0}, {COIN,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {COIN,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x00}, {BLOC,0}, {BLOC,0}, {BLOC,0}, {BLOC,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {COIN,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x00}, {0,0}, {COIN,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x00}, {BLOC,0}, {BLOC,0}, {BLOC,0}, {BLOC,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {BLOC,0}, {BLOC,0}, {BLOC,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {BLOC,0}, {BLOC,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {BLOC,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {TUYAU,0x03}, {TUYAU,0x03}, {TUYAU,0x03}, {TUYAU,0x02}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {TUYAU,0x13}, {TUYAU,0x13}, {TUYAU,0x13}, {TUYAU,0x12}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0x15}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {TUYAU,0x03}, {TUYAU,0x03}, {TUYAU,0x03}, {TUYAU,0x03}, {TUYAU,0x02}, {0,'?'}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {TUYAU,0x13}, {TUYAU,0x13}, {TUYAU,0x13}, {TUYAU,0x13}, {TUYAU,0x12}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,'?'}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {TUYAU,0x03}, {TUYAU,0x03}, {TUYAU,0x02}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {TUYAU,0x13}, {TUYAU,0x13}, {TUYAU,0x12}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, {BRICK,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {BRICK,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x10}, {0,'?'}, {0,0}, {0,0}, {BRICK,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {BRICK,0}, {0,'?'}, {0,0}, {0,0}, {BRICK,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x10}, {0,'?'}, {0,0}, {0,0}, {BRICK,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {BRICK,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {COIN,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {GIFT,0x11}, {0,0}, {0,0}, {0,0}, {0,0}, {COIN,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {COIN,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {TUYAU,0x04}, {TUYAU,0x03}, {TUYAU,0x03}, {TUYAU,0x03}, {TUYAU,0x03}, {TUYAU,0x03}, {TUYAU,0x03}, {TUYAU,0x03}, {TUYAU,0x03}, {TUYAU,0x03}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {TUYAU,0x14}, {TUYAU,0x13}, {TUYAU,0x13}, {TUYAU,0x13}, {TUYAU,0x13}, {TUYAU,0x13}, {TUYAU,0x13}, {TUYAU,0x13}, {TUYAU,0x13}, {TUYAU,0x13}, 
			{EARTH,0x11}, {EARTH,0x01}, {EARTH,0x01}, {EARTH,0x01}, {EARTH,0x01}, {EARTH,0x01}, {EARTH,0x01}, {EARTH,0x01}, {EARTH,0x01}, {EARTH,0x01}, {EARTH,0x01}, {EARTH,0x01}, {EARTH,0x01}, {EARTH,0x00}, 
			{EARTH,0x11}, {EARTH,0x21}, {EARTH,0x21}, {EARTH,0x21}, {EARTH,0x21}, {EARTH,0x21}, {EARTH,0x21}, {EARTH,0x20}, {TUYAU,0x03}, {TUYAU,0x03}, {EARTH,0x21}, {EARTH,0x21}, {EARTH,0x11}, {EARTH,0x10}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {TUYAU,0x11}, {TUYAU,0x10}, {0,0}, {0,0}, {EARTH,0x11}, {EARTH,0x10}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {TUYAU,0x21}, {TUYAU,0x20}, {0,0}, {0,0}, {EARTH,0x11}, {EARTH,0x10}, 
			{EARTH,0x10}, {0,0}, {COIN,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {EARTH,0x11}, {EARTH,0x10}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {EARTH,0x11}, {EARTH,0x10}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {EARTH,0x11}, {EARTH,0x10}, 
			{EARTH,0x10}, {0,0}, {COIN,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {EARTH,0x11}, {EARTH,0x10}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {EARTH,0x11}, {EARTH,0x10}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {COIN,0}, {0,0}, {0,0}, {EARTH,0x11}, {EARTH,0x10}, 
			{EARTH,0x10}, {0,0}, {COIN,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {EARTH,0x11}, {EARTH,0x10}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, {0,0}, {0,0}, {0,0}, {0,0}, {EARTH,0x11}, {EARTH,0x10}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {EARTH,0x11}, {EARTH,0x10}, 
			{EARTH,0x10}, {0,0}, {COIN,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {COIN,0}, {0,0}, {EARTH,0x11}, {EARTH,0x10}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {EARTH,0x11}, {EARTH,0x10}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, {0,0}, {0,0}, {0,0}, {0,0}, {EARTH,0x11}, {EARTH,0x10}, 
			{EARTH,0x10}, {0,0}, {COIN,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {EARTH,0x11}, {EARTH,0x10}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {EARTH,0x11}, {EARTH,0x10}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, {0,0}, {COIN,0}, {0,0}, {EARTH,0x11}, {EARTH,0x10}, 
			{EARTH,0x10}, {0,0}, {COIN,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {EARTH,0x11}, {EARTH,0x10}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {EARTH,0x11}, {EARTH,0x10}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {COIN,0}, {0,0}, {0,0}, {EARTH,0x11}, {EARTH,0x10}, 
			{EARTH,0x10}, {0,0}, {COIN,0}, {0,0}, {0,0}, {0,0}, {BRICK,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {EARTH,0x11}, {EARTH,0x10}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {EARTH,0x11}, {EARTH,0x10}, 
			{EARTH,0x20}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {EARTH,0x11}, {EARTH,0x10}, 
			{TUYAU,0x03}, {TUYAU,0x03}, {TUYAU,0x02}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,'?'}, {0,0}, {0,0}, {EARTH,0x11}, {EARTH,0x10}, 
			{TUYAU,0x13}, {TUYAU,0x13}, {TUYAU,0x12}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {EARTH,0x11}, {EARTH,0x10}, 
			{EARTH,0x01}, {EARTH,0x01}, {EARTH,0x01}, {EARTH,0x01}, {EARTH,0x01}, {EARTH,0x01}, {EARTH,0x01}, {EARTH,0x01}, {EARTH,0x01}, {EARTH,0x01}, {EARTH,0x01}, {EARTH,0x01}, {EARTH,0x11}, {EARTH,0x10}, 
			{EARTH,0x11}, {EARTH,0x21}, {EARTH,0x21}, {EARTH,0x21}, {EARTH,0x21}, {EARTH,0x21}, {EARTH,0x21}, {EARTH,0x21}, {EARTH,0x21}, {EARTH,0x21}, {EARTH,0x21}, {EARTH,0x21}, {EARTH,0x21}, {EARTH,0x20}, 
			{EARTH,0x20}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{TUYAU,0x03}, {TUYAU,0x03}, {TUYAU,0x02}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{TUYAU,0x13}, {TUYAU,0x13}, {TUYAU,0x12}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x00}, {BLOC,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x10}, {BLOC,0}, {BLOC,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x10}, {BLOC,0}, {BLOC,0}, {BLOC,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x10}, {BLOC,0}, {BLOC,0}, {BLOC,0}, {BLOC,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x10}, {BLOC,0}, {BLOC,0}, {BLOC,0}, {BLOC,0}, {BLOC,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x10}, {BLOC,0}, {BLOC,0}, {BLOC,0}, {BLOC,0}, {BLOC,0}, {BLOC,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x10}, {BLOC,0}, {BLOC,0}, {BLOC,0}, {BLOC,0}, {BLOC,0}, {BLOC,0}, {BLOC,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x10}, {BLOC,0}, {BLOC,0}, {BLOC,0}, {BLOC,0}, {BLOC,0}, {BLOC,0}, {BLOC,0}, {BLOC,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x10}, {BLOC,0}, {BLOC,0}, {BLOC,0}, {BLOC,0}, {BLOC,0}, {BLOC,0}, {BLOC,0}, {BLOC,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x10}, {BLOC,0}, {END_LEVEL,0x1102},{END_LEVEL,0x1102},{END_LEVEL,0x1102},{END_LEVEL,0x1102},{END_LEVEL,0x1202}, {END_LEVEL,0x1202}, {END_LEVEL,0x1202}, {END_LEVEL,0x1302}, {END_LEVEL,0x1401}, {END_LEVEL,0x1400}, {0,0}, {0,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
			{EARTH,0x10}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, 
		};
		init_level(lvl);

		ennemi_t ennemies0[]={
			GOOMBA(152, 8, -1),
			GOOMBA(168, 8, -1),
			GOOMBA(264, 8, -1),
			GOOMBA(408, 8, -1),
			GOOMBA(424, 8, -1),
			KOOPA_V(440, 8, -1),
			KOOPA_R(552, 40, -1),
			KOOPA_R(664, 32, -1),
			GOOMBA(792, 64, -1),
			GOOMBA(800, 88, -1),
			GOOMBA(896, 8, -1),
			KOOPA_R(1024, 40, -1),
			GOOMBA(1152, 8, -1),
			GOOMBA(1168, 8, -1),
			KOOPA_V(1184, 8, -1),
			KOOPA_V(1480, 8, -1),
			GOOMBA(1560, 8, -1),
			KOOPA_R(1568, 40, -1),
			GOOMBA(1576, 8, -1),
		};
		ennemis_global_size=12;
		init_ennemies(ennemies0);

// !e End of generated section

		teleport_t t[]=
		{
			{106,4,  222,9, MK_DOWN},
			{243,3, 174,4, MK_DOWN},
			{216,3,  248,2, MK_UP},
		};

		set_teleporteurs(t, sizeof(t)/sizeof(teleport_t));

	}*/
}

void get_lvl_id(int w, int l, char * str)
{
	str[3]='\0';
	sprintf(str, "%d-%d", w+1, l+1);
}
